use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
App
Cmd
Command
Crowell
Daisuke
Dann
Etheridge
Gardner
Graham
Guillermo
Inc
Infinity
Interactive
Joyce
Karen
Kaye
Ken
Knop
Kogman
Maki
Mark
Michael
MooseX
Offer
Roditi
Yuval
brunov
dmaki
ether
groditi
haarg
irc
lib
mjgardner
nothingmuch
oeuftete
offer
techmemo
ubermichael
vecchi
vovkasm
יובל
קוג
